@@ -1246,14 +1246,10 @@ class RoleManagerServer(Server):
 
         cmd = pkt.service_command
 
-        if cmd == JD_ROLE_MANAGER_CMD_LIST_REQUIRED_ROLES:
-            self.handle_list_required_roles(pkt)
-        elif cmd == JD_ROLE_MANAGER_CMD_LIST_STORED_ROLES:
-            self.handle_list_stored_roles(pkt)
+        if cmd == JD_ROLE_MANAGER_CMD_LIST_ROLES:
+            self.handle_list_roles(pkt)
         elif cmd == JD_ROLE_MANAGER_CMD_CLEAR_ALL_ROLES:
             self.handle_clear_all_roles(pkt)
-        elif cmd == JD_ROLE_MANAGER_CMD_GET_ROLE:
-            self.handle_get_role(pkt)
         elif cmd == JD_ROLE_MANAGER_CMD_SET_ROLE:
             self.handle_set_role(pkt)
         elif cmd == JD_GET(JD_ROLE_MANAGER_REG_ALL_ROLES_ALLOCATED):
@@ -1261,7 +1257,7 @@ class RoleManagerServer(Server):
         else:
             super().handle_packet(pkt)
 
-    def handle_list_required_roles(self, pkt: JDPacket):
+    def handle_list_roles(self, pkt: JDPacket):
         pipe = OutPipe(self.bus, pkt)
         for client in self.bus.all_clients:
             device_id = bytearray(0)
@@ -1275,29 +1271,6 @@ class RoleManagerServer(Server):
             pipe.write(bytearray(payload))
         pipe.close()
 
-    def handle_list_stored_roles(self, pkt: JDPacket):
-        pipe = OutPipe(self.bus, pkt)
-        for key, payload in self.settings.list():
-            device_id, service_index = key.split(":")
-            role = jdunpack(payload, "s")[0]
-            pipe.write(bytearray(
-                jdpack("b[8] u8 s", bytearray.fromhex(device_id), service_index, role)))
-        pipe.close()
-
-    def handle_get_role(self, pkt: JDPacket):
-        payload = pkt.unpack("b[8] u8")
-        device_id_b = cast(bytearray, payload[0])
-        device_id = device_id_b.hex()
-        service_index = cast(int, payload[1])
-
-        role = ""
-        for client in self.bus.all_clients:
-            if client.device and client.device.device_id == device_id and client.service_index == service_index:
-                role = client.role
-                break
-        self.send_report(JDPacket.packed(
-            JD_ROLE_MANAGER_CMD_GET_ROLE, "u[8] u8 s", device_id_b, service_index, role))
-
     def handle_all_roles_allocated(self, pkt: JDPacket):
         res = 1
         for client in self.bus.all_clients:
